@@ -20,7 +20,8 @@
          $SQLDatabaseUserLookup, $SQLDatabaseServiceLevelLookup,
          $default_org_logo, $rawLoginIsOutgoingEmailAddress,
          $dontUseHostNameUserList, $always_prepend, $always_append,
-         $IMAPServerRules, $SMTPServerRules;
+         $IMAPServerRules, $SMTPServerRules, $postProcessingPattern,
+         $postProcessingReplacement;
 
 
 
@@ -505,6 +506,39 @@
   $sendmailVirtualUserTable = '';
 
 
+  // Final arbitrary replacements may be done on the full IMAP
+  // username, after all other username processing is complete.
+  //
+  // The $postProcessingPattern must specify a full regular 
+  // expression pattern (including delimiters and modifiers),
+  // or an array thereof.  $postProcessingReplacement should 
+  // specify a replacement string or array thereof, or be left
+  // blank, in which case all patterns will be removed.  These
+  // two values are plugged directly into preg_replace(), so
+  // the documentation here applies:
+  // http://www.php.net/manual/function.preg-replace.php
+  // 
+  // Exaples:
+  //
+  //$postProcessingPattern = '/@/';
+  //$postProcessingReplacement = '.';
+  //
+  //$postProcessingPattern = '/@/';
+  //$postProcessingReplacement = '';
+  //
+  //$postProcessingPattern = array('/jack/i', '/jill/i');
+  //$postProcessingReplacement = 'spot';
+  //
+  //$postProcessingPattern = array('/jack/i', '/jill/i');
+  //$postProcessingReplacement = array('jill', 'jack');
+  //
+  //$postProcessingPattern = array('/jack/i', '/jill/i');
+  //$postProcessingReplacement = '';
+  //
+  $postProcessingPattern = '';
+  $postProcessingReplacement = '';
+
+
   // This is the path to the hostname translation table, which
   // should be empty if you do not need to remap the domain
   // host name that your users will be logging in from
